package
Version:
v1.6.1
Opens a new window with list of versions in this module.
Published: Sep 16, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Migration struct {
ID uint `gorm:"primarykey"`
Migration string `gorm:""`
Batch uint8 `gorm:""`
}
Migration model for database migrations
Source Files
¶
Click to show internal directories.
Click to hide internal directories.